Module: Devise::Models::Compatibility::ActiveRecordPatch

Extended by:
ActiveSupport::Concern
Defined in:
lib/devise-security/models/compatibility/active_record_patch.rb

Instance Method Summary collapse

Instance Method Details

#encrypted_password_before_last_saveString?

The encrypted password that existed before the record was saved

Returns:

  • (String)
  • (nil)

    if an encrypted_password had not been set



21
22
23
# File 'lib/devise-security/models/compatibility/active_record_patch.rb', line 21

def encrypted_password_before_last_save
  previous_changes['encrypted_password'].try(:first)
end

#saved_change_to_encrypted_password?Boolean

When the record was saved, was the encrypted_password changed?

Returns:

  • (Boolean)


14
15
16
# File 'lib/devise-security/models/compatibility/active_record_patch.rb', line 14

def saved_change_to_encrypted_password?
  encrypted_password_changed?
end

#update_attribute_without_validatons_or_callbacks(name, value) ⇒ Object

Updates the record with the value and does not trigger validations or callbacks

Parameters:

  • name (Symbol)

    attribute to update

  • value (String)

    value to set



35
36
37
# File 'lib/devise-security/models/compatibility/active_record_patch.rb', line 35

def update_attribute_without_validatons_or_callbacks(name, value)
  update_column(name, value)
end

#will_save_change_to_encrypted_password?Boolean

When the record is saved, will the encrypted_password be changed?

Returns:

  • (Boolean)


27
28
29
# File 'lib/devise-security/models/compatibility/active_record_patch.rb', line 27

def will_save_change_to_encrypted_password?
  changed_attributes['encrypted_password'].present?
end